@@ -72,6 +72,11 @@ HTTP_X_IDENTITY_STATUS, HTTP_X_SERVICE_IDENTITY_STATUS
     presented. This allows the underlying service to determine if a
     denial should use ``401 Unauthenticated`` or ``403 Forbidden``.
 
+HTTP_OPENSTACK_SYSTEM_SCOPE
+    A string relaying system information about the token's scope. This
+    attribute is only present if the token is system-scoped. The string ``all``
+    means the token is scoped to the entire deployment system.
+
 HTTP_X_DOMAIN_ID, HTTP_X_SERVICE_DOMAIN_ID
     Identity service managed unique identifier, string. Only present if
     this is a domain-scoped token.
@@ -190,7 +195,7 @@ configuration file, e.g. in ``nova.conf``:
 
   [keystone_authtoken]
   auth_plugin = password
-  auth_url = http://keystone:35357/
+  auth_url = http://keystone:5000/
   username = nova
   user_domain_id = default
   password = whyarewestillusingpasswords
@@ -214,8 +219,6 @@ object is stored.
 
 import binascii
 import copy
-import datetime
-import warnings
 
 from keystoneauth1 import access
 from keystoneauth1 import adapter
@@ -239,7 +242,6 @@ from keystonemiddleware.auth_token import _exceptions as ksm_exceptions
 from keystonemiddleware.auth_token import _identity
 from keystonemiddleware.auth_token import _opts
 from keystonemiddleware.auth_token import _request
-from keystonemiddleware.auth_token import _revocations
 from keystonemiddleware.auth_token import _signing_dir
 from keystonemiddleware.auth_token import _user_plugin
 from keystonemiddleware.i18n import _
@@ -309,12 +311,6 @@ class BaseAuthProtocol(object):
                                    perform.
     """
 
-    # NOTE(jamielennox): Default to True and remove in Queens. This is a
-    # compatibility flag to allow passing **kwargs to fetch_token(). This
-    # is basically to allow compatibility with keystone's override. We will
-    # assume all subclasses are ok with this being True in the Queens release.
-    kwargs_to_fetch_token = False
-
     def __init__(self,
                  app,
                  log=_LOG,
@@ -378,9 +374,9 @@ class BaseAuthProtocol(object):
                 check = self._service_token_roles.intersection(role_names)
                 role_check_passed = bool(check)
 
-                # if service_token_role_required then the service token is only
-                # valid if the roles check out. Otherwise at this point it is
-                # true because keystone has already validated it.
+                # if service_token_roles_required then the service token is
+                # only valid if the roles check out. Otherwise at this point it
+                # is true because keystone has already validated it.
                 if self._service_token_roles_required:
                     request.service_token_valid = role_check_passed
                 else:
@@ -436,14 +432,7 @@ class BaseAuthProtocol(object):
         # NOTE(edmondsw): strip the token to remove any whitespace that may
         # have been passed along in the header per bug 1689468
         token = token.strip()
-        if self.kwargs_to_fetch_token:
-            data = self.fetch_token(token, **kwargs)
-        else:
-            m = _('Implementations of auth_token must set '
-                  'kwargs_to_fetch_token this will be the required and '
-                  'assumed in Queens.')
-            warnings.warn(m)
-            data = self.fetch_token(token)
+        data = self.fetch_token(token, **kwargs)
 
         try:
             return data, access.create(body=data, auth_token=token)
@@ -549,8 +538,6 @@ class AuthProtocol(BaseAuthProtocol):
     _SIGNING_CERT_FILE_NAME = 'signing_cert.pem'
     _SIGNING_CA_FILE_NAME = 'cacert.pem'
 
-    kwargs_to_fetch_token = True
-
     def __init__(self, app, conf):
         log = logging.getLogger(conf.get('log_name', __name__))
         log.info('Starting Keystone auth_token middleware')
@@ -559,7 +546,7 @@ class AuthProtocol(BaseAuthProtocol):
                                    _base.AUTHTOKEN_GROUP,
                                    list_opts(),
                                    conf)
-        if self._conf.oslo_conf_obj != cfg.CONF:
+        if self._conf.oslo_conf_obj is not cfg.CONF:
             oslo_cache.configure(self._conf.oslo_conf_obj)
 
         token_roles_required = self._conf.get('service_token_roles_required')
@@ -608,17 +595,6 @@ class AuthProtocol(BaseAuthProtocol):
 
         self._token_cache = self._token_cache_factory()
 
-        revocation_cache_timeout = datetime.timedelta(
-            seconds=self._conf.get('revocation_cache_time'))
-        self._revocations = _revocations.Revocations(revocation_cache_timeout,
-                                                     self._signing_directory,
-                                                     self._identity_server,
-                                                     self._cms_verify,
-                                                     self.log)
-
-        self._check_revocations_for_cached = self._conf.get(
-            'check_revocations_for_cached')
-
     def process_request(self, request):
         """Process request.
 
@@ -695,15 +671,12 @@ class AuthProtocol(BaseAuthProtocol):
 
     @property
     def _reject_auth_headers(self):
-        header_val = 'Keystone uri=\'%s\'' % self._www_authenticate_uri
+        header_val = 'Keystone uri="%s"' % self._www_authenticate_uri
         return [('WWW-Authenticate', header_val)]
 
     def _token_hashes(self, token):
         """Generate a list of hashes that the current token may be cached as.
 
-        With PKI tokens we have multiple hashing algorithms that we test with
-        revocations. This generates that whole list.
-
         The first element of this list is the preferred algorithm and is what
         new cache values should be saved as.
 
@@ -751,11 +724,6 @@ class AuthProtocol(BaseAuthProtocol):
                     self.log.debug('Cached token is marked unauthorized')
                     raise ksm_exceptions.InvalidToken()
 
-                if self._check_revocations_for_cached:
-                    # A token might have been revoked, regardless of initial
-                    # mechanism used to validate it, and needs to be checked.
-                    self._revocations.check(token_hashes)
-
                 # NOTE(jamielennox): Cached values used to be stored as a tuple
                 # of data and expiry time. They no longer are but we have to
                 # allow some time to transition the old format so if it's a
@@ -774,11 +742,17 @@ class AuthProtocol(BaseAuthProtocol):
                 self._token_cache.set(token_hashes[0], data)
 
         except (ksa_exceptions.ConnectFailure,
+                ksa_exceptions.DiscoveryFailure,
                 ksa_exceptions.RequestTimeout,
-                ksm_exceptions.RevocationListError,
                 ksm_exceptions.ServiceError) as e:
             self.log.critical('Unable to validate token: %s', e)
-            raise webob.exc.HTTPServiceUnavailable()
+            if self._delay_auth_decision:
+                self.log.debug('Keystone unavailable; marking token as '
+                               'invalid and deferring auth decision.')
+                raise ksm_exceptions.InvalidToken(
+                    'Keystone unavailable: %s' % e)
+            raise webob.exc.HTTPServiceUnavailable(
+                'The Keystone service is temporarily unavailable.')
         except ksm_exceptions.InvalidToken:
             self.log.debug('Token validation failure.', exc_info=True)
             if token_hashes:
@@ -786,6 +760,10 @@ class AuthProtocol(BaseAuthProtocol):
                                       _CACHE_INVALID_INDICATOR)
             self.log.warning('Authorization failed for token')
             raise
+        except ksa_exceptions.EndpointNotFound:
+            # Invalidate auth in adapter for identity endpoint update
+            self._identity_server.invalidate()
+            raise
 
         return data
 
@@ -801,14 +779,10 @@ class AuthProtocol(BaseAuthProtocol):
             return
 
         try:
-            self._revocations.check(token_hashes)
             verified = self._cms_verify(token_data, inform)
         except ksc_exceptions.CertificateConfigError:
             self.log.warning('Fetch certificate config failed, '
                              'fallback to online validation.')
-        except ksm_exceptions.RevocationListError:
-            self.log.warning('Fetch revocation list failed, '
-                             'fallback to online validation.')
         else:
             self.log.warning('auth_token middleware received a PKI/Z token. '
                              'This form of token is deprecated and has been '
@@ -819,17 +793,6 @@ class AuthProtocol(BaseAuthProtocol):
 
             data = jsonutils.loads(verified)
 
-            audit_ids = None
-            if 'access' in data:
-                # It's a v2 token.
-                audit_ids = data['access']['token'].get('audit_ids')
-            else:
-                # It's a v3 token
-                audit_ids = data['token'].get('audit_ids')
-
-            if audit_ids:
-                self._revocations.check_by_audit_id(audit_ids)
-
             return data
 
     def _validate_token(self, auth_ref, **kwargs):
@@ -1009,4 +972,3 @@ def app_factory(global_conf, **local_conf):
 InvalidToken = ksm_exceptions.InvalidToken
 ServiceError = ksm_exceptions.ServiceError
 ConfigurationError = ksm_exceptions.ConfigurationError
-RevocationListError = ksm_exceptions.RevocationListError
