@@ -55,7 +55,6 @@ class OptsTestCase(utils.TestCase):
             'signing_dir',
             'memcached_servers',
             'token_cache_time',
-            'revocation_cache_time',
             'memcache_security_strategy',
             'memcache_secret_key',
             'memcache_use_advanced_pool',
@@ -66,7 +65,6 @@ class OptsTestCase(utils.TestCase):
             'memcache_pool_socket_timeout',
             'include_service_catalog',
             'enforce_token_bind',
-            'check_revocations_for_cached',
             'hash_algorithms',
             'auth_type',
             'auth_section',
@@ -102,7 +100,6 @@ class OptsTestCase(utils.TestCase):
             'signing_dir',
             'memcached_servers',
             'token_cache_time',
-            'revocation_cache_time',
             'memcache_security_strategy',
             'memcache_secret_key',
             'memcache_use_advanced_pool',
@@ -113,7 +110,6 @@ class OptsTestCase(utils.TestCase):
             'memcache_pool_socket_timeout',
             'include_service_catalog',
             'enforce_token_bind',
-            'check_revocations_for_cached',
             'hash_algorithms',
             'auth_type',
             'auth_section',
